<?php
/************************************************************************
 * Mailer v0.2.1-FINAL                                Start: 05/28/2007 *
 * ===================                          Last change: 05/31/2007 *
 *                                                                      *
 * -------------------------------------------------------------------- *
 * File              : ext-bank.php                                     *
 * -------------------------------------------------------------------- *
 * Short description : A little bank account                            *
 * -------------------------------------------------------------------- *
 * Kurzbeschreibung  : Ein einfaches Bankaccount                        *
 * -------------------------------------------------------------------- *
 * $Revision::                                                        $ *
 * $Date::                                                            $ *
 * $Tag:: 0.2.1-FINAL                                                 $ *
 * $Author::                                                          $ *
 * -------------------------------------------------------------------- *
 * Copyright (c) 2003 - 2009 by Roland Haeder                           *
 * Copyright (c) 2009 - 2012 by Mailer Developer Team                   *
 * For more information visit: http://mxchange.org                      *
 *                                                                      *
 * This program is free software; you can redistribute it and/or modify *
 * it under the terms of the GNU General Public License as published by *
 * the Free Software Foundation; either version 2 of the License, or    *
 * (at your option) any later version.                                  *
 *                                                                      *
 * This program is distributed in the hope that it will be useful,      *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of       *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
 * GNU General Public License for more details.                         *
 *                                                                      *
 * You should have received a copy of the GNU General Public License    *
 * along with this program; if not, write to the Free Software          *
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,               *
 * MA  02110-1301  USA                                                  *
 ************************************************************************/

// Some security stuff...
if (!defined('__SECURITY')) {
	die();
} // END - if

// Version number
setThisExtensionVersion('0.0.0');

// Version history array (add more with , '0.0.1' and so on)
setExtensionVersionHistory(array('0.0.0'));

// This extension is in development (non-productive)
enableExtensionProductive(false);

switch (getExtensionMode()) {
	case 'register': // Do stuff when installation is running
		// SQL commands to run
		addDropTableSql('bank_accounts');
		addCreateTableSql('bank_accounts', "
`id` BIGINT(20) UNSIGNED NOT NULL AUTO_INCREMENT,
`userid` BIGINT(20) UNSIGNED NOT NULL DEFAULT 0,
`account_created` BIGINT(20) UNSIGNED NOT NULL DEFAULT 0,
`account_locked` BIGINT(20) UNSIGNED NOT NULL DEFAULT 0,
`locked_reason` TINYTEXT,
`status` ENUM('NEW','ACTIVE','LOCKED') NOT NULL DEFAULT 'NEW',
`account_balance` FLOAT(20,5) UNSIGNED NOT NULL DEFAULT 0.00000,
`output_mode` ENUM('LOGIN','EMAIL','DISABLED'),
`pin` VARCHAR(50) NOT NULL DEFAULT '',
`tan_mode` ENUM('NORMAL','INDEXED'),
`tan_list_status` ENUM('PENDING','ACTIVE','INVALID','LOCKED') NOT NULL DEFAULT 'PENDING',
`tan_key` VARCHAR(50) NOT NULL DEFAULT '',
`month_transfered` BIGINT(20) UNSIGNED NOT NULL DEFAULT 0,
`last_tan` VARCHAR(5) NOT NULL DEFAULT '00000',
`last_tan_stamp` BIGINT(20) UNSIGNED NOT NULL DEFAULT 0,
`last_tan_purpose` TINYTEXT,
`account_type` ENUM('CHECK','SAVING') NOT NULL DEFAULT 'CHECK',
`overdraft_credit` FLOAT(20,5) UNSIGNED NOT NULL DEFAULT 0.00000,
PRIMARY KEY (`id`),
UNIQUE (`pin`),
INDEX `userid_type` (`userid`,`account_type`),
INDEX (`account_created`),
INDEX (`account_locked`),
INDEX (`last_tan_stamp`)",
			'User bank accounts data');

		addDropTableSql('bank_transfers');
		addCreateTableSql('bank_transfers', "
`id` BIGINT(20) UNSIGNED NOT NULL AUTO_INCREMENT,
`to_account_id` BIGINT(20) UNSIGNED NOT NULL DEFAULT 0,
`from_account_id` BIGINT(20) UNSIGNED NOT NULL DEFAULT 0,
`points_amount` FLOAT(20,5) UNSIGNED NOT NULL DEFAULT 0.00000,
`day_bookkeeping` CHAR(4) NOT NULL DEFAULT '0000',
`day_available` CHAR(4) NOT NULL DEFAULT '0000',
`transfer_purpose` TINYTEXT,
PRIMARY KEY (`id`),
INDEX (`to_account_id`,`from_account_id`),
INDEX (`day_bookkeeping`,`day_available`)",
			'Bank user->user transfers');

		addDropTableSql('bank_packages');
		addCreateTableSql('bank_packages', "
`id` BIGINT(20) UNSIGNED NOT NULL AUTO_INCREMENT,
`title` VARCHAR(255) NOT NULL DEFAULT '',
`description` TINYTEXT,
`account_fee` FLOAT(20,5) UNSIGNED NOT NULL DEFAULT 0.00000,
`free_transfers` INT(7) UNSIGNED NOT NULL DEFAULT 0,
`transfer_fee` FLOAT(20,5) UNSIGNED NOT NULL DEFAULT 0.00000,
`available` TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP,
`output_system_mode` ENUM('LOGIN','EMAIL','DISABLED'),
`package_active` ENUM('Y','N') NOT NULL DEFAULT 'N',
`free_months_no_fee` TINYINT(3) UNSIGNED NOT NULL DEFAULT 0,
`interest_plus` FLOAT(7,5) UNSIGNED NOT NULL DEFAULT 0.00000,
`interest_minus` FLOAT(7,5) UNSIGNED NOT NULL DEFAULT 0.00000,
`first_payment` FLOAT(20,5) UNSIGNED NOT NULL DEFAULT 0.00000,
`free_account_income` FLOAT(20,5) UNSIGNED NOT NULL DEFAULT 0.00000,
`free_account_stuff` TINYTEXT null,
`tan_lock` TINYINT(3) UNSIGNED NOT NULL DEFAULT 0,
PRIMARY KEY (`id`)",
			'Bank account packages');

		// Free_account_stuff will be a list of columns of the table _bank_packages
		// what the member shall get for the specified income. output_system_mode
		// must be extended with the mode you get for free: output_system_mode:LOGIN
		// should be fine. More than one entry and not DISABLED ;) are not supported.
		addDropTableSql('bank_tanlist');
		addCreateTableSql('bank_tanlist', "
`id` BIGINT(20) UNSIGNED NOT NULL AUTO_INCREMENT,
`idx` TINYINT(3) UNSIGNED NOT NULL DEFAULT 0,
`account_id` BIGINT(20) UNSIGNED NOT NULL DEFAULT 0,
`tan` VARCHAR(50) NOT NULL DEFAULT '',
`used` ENUM('Y','N') NOT NULL DEFAULT 'N',
PRIMARY KEY (`id`),
UNIQUE (`account_id`,`tan`)",
			'Bank TAN lists per user');

		// Admin menu queries
		addAdminMenuSql('bank', NULL, 'Bank-Accounts', 'Verwalten Sie hier alle Bank-Accounts Ihrer Mitglieder, sowie Angebotspakete und &Uuml;berweisungen.', 6);
		addAdminMenuSql('bank', 'add_bank_package', 'Angebotspaket hinzuf&uuml;gen', 'Neues Angebotspaket erstellen.', 1);
		addAdminMenuSql('bank', 'list_bank_package', 'Angebotspakete auflisten', 'Listet alle erstellten Angebotspakete auf.', 2);
		addAdminMenuSql('bank', 'edit_bank_package', 'Angebotspaket &auml;ndern', 'Nach Auswahl eines Angebotspaketes k&ouml;nnen Sie dieses hier ver&auml;ndern. Bitte beachten Sie, dass Ihre Mitglieder keine Mail dabei erhalten!', 3);
		addAdminMenuSql('bank', 'lock_bank_package', 'Angebotspaket ent-/sperren', 'Nehmen Sie Angebotspakete zur tempor&auml;ren &Uuml;berarbeitung zuvor heraus, dann k&ouml;nnen Sie in Ruhe dr&uuml;ber nachdenken und Berechnungen anstellen. Freigabe ist hier auch m&ouml;glich.', 4);
		addAdminMenuSql('bank', 'del_bank_package', 'Angebotspaket l&ouml;schen', 'Nach Auswahl eines Angebotspaketes k&ouml;nnen Sie mit abschliessender Best&auml;tigung Angebotspakete ganz l&ouml;schen. Bitte beachten Sie, dass dies nur m&ouml;glich ist, wenn auch alle Accounts dieses nicht mehr nutzen!', 5);
		addAdminMenuSql('bank', 'add_bank_account', 'Konto anlegen', 'Legen Sie hier Konten f&uuml;r die Mitglieder an (falls Ihre Mitglieder nicht zurecht kommen).', 6);
		addAdminMenuSql('bank', 'list_bank_account', 'Konten auflisten', 'Auflistung aller Konto oder eines ausw&auml;hlbaren Mitglieds.', 7);
		addAdminMenuSql('bank', 'edit_bank_account', 'Konto &auml;ndern', '&Auml;ndern Sie hier bestehende Konten, z.B. den Dispositionskredit usw. PINs und TANs sind hier nicht &auml;nderbar! Best&auml;tigungsmails sind optional versendbar.', 8);
		addAdminMenuSql('bank', 'lock_bank_account', 'Konto ent-/sperren', 'Sperren Sie hier Konten bei Bedarf. Auch das Freischalten ist hier m&ouml;glich. Eine Benachrichtigung per Mail wird dann an das Mitglied ausgesendet.', 9);
		addAdminMenuSql('bank', 'del_bank_account', 'Konto l&ouml;schen', 'L&ouml;schen von Konten mit Best&auml;tigungsmail. Wenn Sie ein Mitglieder-Account l&ouml;schen, so m&uuml;ssen Sie derzeit seine angelegten Konten auch l&ouml;schen!', 10);
		addAdminMenuSql('bank', 'send_bank_tanlist', 'TAN-Liste aussenden', 'Listet zuerst Anfragen von Mitgliedern auf, die eine neue (i)TAN-Liste ben&ouml;tigen, anschliessend kann die Liste dann ausgesendet werden.', 11);
		addAdminMenuSql('bank', 'lock_bank_tanlist', 'TAN-Liste ent-/sperren', 'Bestehende TAN-Listen k&ouml;nnen auf Kundenwunsch hin gesperrt und wieder entsperrt werden. Dies passiert auch, wenn der Kunde x-mal (siehe Angebotspakete) eine verkehrte TAN eingegeben hat. Einzelne TANs sind nicht ent-/sperrbar.', 12);
		addAdminMenuSql('bank', 'list_bank_trans', '&Uuml;berweisungen auflisten', 'Nach Auswahl eines Mitgliedes und einem Konto (ben&ouml;tgt JavaScript!) k&ouml;nnen Sie seitenweise die &Uuml;berweisungen durchschauen.', 13);

		// Member menu
		addMemberMenuSql('bank', NULL, 'Bank-Account', 3);
		addMemberMenuSql('bank', 'bank_infos', 'Angebotspakete', 1);
		addMemberMenuSql('bank', 'bank_create', 'Konto anlegen', 2);
		addMemberMenuSql('bank', 'bank_deposit', 'Auf Konto einzahlen', 3);
		addMemberMenuSql('bank', 'bank_withdraw', 'Vom Konto abheben', 4);
		addMemberMenuSql('bank', 'bank_output', 'Kontoauszug', 5);
		addMemberMenuSql('bank', 'bank_change', 'Paket wechseln', 6);
		addMemberMenuSql('bank', 'bank_remove', 'Konto K&uuml;ndigen', 7);
		break;

	case 'remove': // Do stuff when removing extension
		// SQL commands to run
		addDropTableSql('bank_accounts');
		addDropTableSql('bank_transfers');
		addDropTableSql('bank_packages');
		addDropTableSql('bank_tanlist');
		addExtensionSql("DELETE LOW_PRIORITY FROM `{?_MYSQL_PREFIX?}_admin_menu` WHERE `action`='bank'");
		addExtensionSql("DELETE LOW_PRIORITY FROM `{?_MYSQL_PREFIX?}_member_menu` WHERE `action`='bank'");
		break;

	case 'activate': // Do stuff when admin activates this extension
		// SQL commands to run
		addExtensionSql("UPDATE `{?_MYSQL_PREFIX?}_member_menu` SET `visible`='Y',`locked`='N' WHERE `action`='bank' LIMIT 8");
		break;

	case 'deactivate': // Do stuff when admin deactivates this extension
		// SQL commands to run
		addExtensionSql("UPDATE `{?_MYSQL_PREFIX?}_member_menu` SET `visible`='N',`locked`='Y' WHERE `action`='bank' LIMIT 8");
		break;

	case 'update': // Update an extension
		switch (getCurrentExtensionVersion()) {
			case '0.0.1': // SQL queries for v0.0.1
				addExtensionSql('');

				// Update notes (these will be set as task text!)
				setExtensionUpdateNotes('');
				break;
		} // END - switch
		break;

	case 'modify': // When the extension got modified
		break;

	case 'test': // For testing purposes
		break;

	case 'init': // Do stuff when extension is initialized
		break;

	default: // Unknown extension mode
		logDebugMessage(__FILE__, __LINE__, sprintf("Unknown extension mode %s in extension %s detected.", getExtensionMode(), getCurrentExtensionName()));
		break;
} // END - switch

// [EOF]
?>
