<?php
/************************************************************************
 * Mailer v0.2.1-FINAL                                Start: 06/02/2011 *
 * ===================                          Last change: 06/02/2011 *
 *                                                                      *
 * -------------------------------------------------------------------- *
 * File              : _filter.php                                      *
 * -------------------------------------------------------------------- *
 * Short description : Filters for ext-                                 *
 * -------------------------------------------------------------------- *
 * Kurzbeschreibung  : Filter fuer ext-                                 *
 * -------------------------------------------------------------------- *
 * $Revision::                                                        $ *
 * $Date::                                                            $ *
 * $Tag:: 0.2.1-FINAL                                                 $ *
 * $Author::                                                          $ *
 * -------------------------------------------------------------------- *
 * Copyright (c) 2003 - 2009 by Roland Haeder                           *
 * Copyright (c) 2009 - 2012 by Mailer Developer Team                   *
 * For more information visit: http://mxchange.org                      *
 *                                                                      *
 * This program is free software; you can redistribute it and/or modify *
 * it under the terms of the GNU General Public License as published by *
 * the Free Software Foundation; either version 2 of the License, or    *
 * (at your option) any later version.                                  *
 *                                                                      *
 * This program is distributed in the hope that it will be useful,      *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of       *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
 * GNU General Public License for more details.                         *
 *                                                                      *
 * You should have received a copy of the GNU General Public License    *
 * along with this program; if not, write to the Free Software          *
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,               *
 * MA  02110-1301  USA                                                  *
 ************************************************************************/

// Some security stuff...
if (!defined('__SECURITY')) {
	die();
} // END - if

// Destroy the cache on extension changes
function FILTER_CACHE_DESTROY_ON_EXT_CHANGE ($filterData) {
	// Return the data anyway if there is no cache extension
	//* DEBUG: */ logDebugMessage(__FUNCTION__, __LINE__, 'Called!');
	if (!isCacheInstanceValid()) {
		return false;
	} // END - if

	// Remove cache
	foreach (array('config', 'extension', 'filter', 'modules', 'earning', 'points_data') as $cache) {
		// Is this cache there?
		if ($GLOBALS['cache_instance']->loadCacheFile($cache)) {
			// Yes, then remove it
			$GLOBALS['cache_instance']->removeCacheFile();
		} // END - if
	} // END - foreach

	// Return it
	//* DEBUG: */ logDebugMessage(__FUNCTION__, __LINE__, 'Done!');
	return $filterData;
}

// Destroy the cache on changing admin
function FILTER_CACHE_DESTROY_ON_ADMIN_CHANGE ($filterData) {
	// Skip this step if the cache instance is not there
	//* DEBUG: */ logDebugMessage(__FUNCTION__, __LINE__, 'Called!');
	if (!isCacheInstanceValid()) {
		return false;
	} // END - if

	// Remove cache
	if ($GLOBALS['cache_instance']->loadCacheFile('admin')) {
		$GLOBALS['cache_instance']->removeCacheFile();
	} // END - if

	// Return the data
	//* DEBUG: */ logDebugMessage(__FUNCTION__, __LINE__, 'Done!');
	return $filterData;
}

// Destroy all cache files
function FILTER_CACHE_DESTROY_ALL ($filterData) {
	// Skip this step if the cache instance is not there
	//* DEBUG: */ logDebugMessage(__FUNCTION__, __LINE__, 'Called!');
	if (!isCacheInstanceValid()) {
		return false;
	} // END - if

	// Remove cache files
	foreach (array('admin', 'admin_acls', 'config', 'extension', 'earning', 'filter', 'imprint', 'modules', 'points_data', 'refdepths', 'refsystem', 'themes') as $cache) {
		// Is the cache file readable?
		// @TODO This should be rewritten not to load the cache file for just checking if it is there for save removal.
		if ($GLOBALS['cache_instance']->loadCacheFile($cache)) {
			// Remove the cache file
			$GLOBALS['cache_instance']->removeCacheFile();
		} // END - if
	} // END - foreach

	//* DEBUG: */ logDebugMessage(__FUNCTION__, __LINE__, 'Done!');
	return $filterData;
}

// Filter for purging 'filter' cache
function FILTER_CACHE_DESTROY_FILTER ($filterData) {
	// Skip this step if the cache instance is not there
	//* DEBUG: */ logDebugMessage(__FUNCTION__, __LINE__, 'Called!');
	if ((!isCacheInstanceValid()) || ((isConfigEntrySet('update_filter_usage')) && (getConfig('update_filter_usage') != 'Y'))) {
		return false;
	} // END - if

	// Remove cache files
	if ($GLOBALS['cache_instance']->loadCacheFile('filter')) {
		$GLOBALS['cache_instance']->removeCacheFile();
	} // END - if

	//* DEBUG: */ logDebugMessage(__FUNCTION__, __LINE__, 'Done!');
	return $filterData;
}

// [EOF]
?>
