<?php
/************************************************************************
 * Mailer v0.2.1-FINAL                                Start: 03/10/2009 *
 * ===================                          Last change: 03/10/2009 *
 *                                                                      *
 * -------------------------------------------------------------------- *
 * File              : inc-functions.php                                *
 * -------------------------------------------------------------------- *
 * Short description : Special functions for handling include files     *
 * -------------------------------------------------------------------- *
 * Kurzbeschreibung  : Spezielle Funktionen fuer Include-Dateien        *
 * -------------------------------------------------------------------- *
 * $Revision::                                                        $ *
 * $Date::                                                            $ *
 * $Tag:: 0.2.1-FINAL                                                 $ *
 * $Author::                                                          $ *
 * -------------------------------------------------------------------- *
 * Copyright (c) 2003 - 2009 by Roland Haeder                           *
 * Copyright (c) 2009 - 2012 by Mailer Developer Team                   *
 * For more information visit: http://mxchange.org                      *
 *                                                                      *
 * This program is free software; you can redistribute it and/or modify *
 * it under the terms of the GNU General Public License as published by *
 * the Free Software Foundation; either version 2 of the License, or    *
 * (at your option) any later version.                                  *
 *                                                                      *
 * This program is distributed in the hope that it will be useful,      *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of       *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
 * GNU General Public License for more details.                         *
 *                                                                      *
 * You should have received a copy of the GNU General Public License    *
 * along with this program; if not, write to the Free Software          *
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,               *
 * MA  02110-1301  USA                                                  *
 ************************************************************************/

// Some security stuff...
if (!defined('__SECURITY')) {
	die();
} // END - if

// Init INC_POOL
function initIncludePool ($pool) {
	//* DEBUG: */ logDebugMessage(__FUNCTION__, __LINE__, 'pool=' . $pool);
	$GLOBALS['inc_pool'][$pool] = array();
}

// Setter for INC_POOL
function setIncludePool ($pool, $includePool) {
	//* DEBUG: */ logDebugMessage(__FUNCTION__, __LINE__, 'pool=' . $pool);
	$GLOBALS['inc_pool'][$pool] = (array) $includePool;
}

// Getter for INC_POOL
function getIncludePool ($pool) {
	//* DEBUG: */ logDebugMessage(__FUNCTION__, __LINE__, 'pool=' . $pool);
	// Default is empty pool
	$poolArray = array();

	// Is it set?
	if (isset($GLOBALS['inc_pool'][$pool])) {
		// Return found pool (array)
		$poolArray = $GLOBALS['inc_pool'][$pool];
	} // END - if

	// Return it
	return $poolArray;
}

// Count INC_POOL
function countIncludePool ($pool) {
	//* DEBUG: */ logDebugMessage(__FUNCTION__, __LINE__, 'pool=' . $pool);
	return count($GLOBALS['inc_pool'][$pool]);
}

// Merge INC_POOL into given
function mergeIncludePool ($pool, $includePool) {
	//* DEBUG: */ logDebugMessage(__FUNCTION__, __LINE__, 'pool=' . $pool);
	setIncludePool($pool, merge_array(getIncludePool($pool), $includePool));
}

// Add single include file to INC_POOL
function addIncludeToPool ($pool, $inc) {
	//* DEBUG: */ logDebugMessage(__FUNCTION__, __LINE__, 'pool=' . $pool);
	array_push($GLOBALS['inc_pool'][$pool], $inc);
}

// Remove an include file from INC_POOL
function removeIncludeFromPool ($pool, $inc) {
	//* DEBUG: */ logDebugMessage(__FUNCTION__, __LINE__, 'pool=' . $pool);
	// First look it up
	$key = array_search($inc, getIncludePool($pool));

	// Is it valid?
	if ($key !== false) {
		// Then remove it
		unset($GLOBALS['inc_pool'][$pool][$key]);

		// And sort the list
		asort($GLOBALS['inc_pool'][$pool]);
	} // END - if
}

// Load the whole include pool
function loadIncludePool ($pool) {
	//* DEBUG: */ logDebugMessage(__FUNCTION__, __LINE__, 'pool=' . $pool.' - START');
	foreach (getIncludePool($pool) as $inc) {
		//* DEBUG: */ debugOutput(__FUNCTION__.':inc='.$inc);
		loadIncludeOnce($inc);
	} // END - foreach
	//* DEBUG: */ logDebugMessage(__FUNCTION__, __LINE__, 'pool=' . $pool.' - END');

	// Remove it
	initIncludePool($pool);
}

// Loads an include file and logs any missing files for debug purposes
function loadInclude ($inc) {
	// Do we have cache?
	if (!isset($GLOBALS['inc_loaded'][$inc])) {
		// Is the include file there?
		if (!isIncludeReadable($inc)) {
			// Not there so log it
			reportBug(__FUNCTION__, __LINE__, sprintf("Include file %s not found or deprecated.", $inc));
		} // END - if

		// Add the path. This is why we need a trailing slash in config.php
		$GLOBALS['inc_loaded'][$inc] = getPath() . $inc;
	} // END - if

	// Try to load it
	include($GLOBALS['inc_loaded'][$inc]);
}

// Loads an include file once
function loadIncludeOnce ($inc) {
	// Is it not loaded?
	if (!isset($GLOBALS['load_once'][$inc])) {
		// Mark it as loaded
		$GLOBALS['load_once'][$inc] = 'loaded';

		// Then try to load it
		loadInclude($inc);
	} // END - if
}

// Checks whether an include file (non-FQFN better) is readable
function isIncludeReadable ($inc) {
	// Do we have cache?
	if (!isset($GLOBALS['inc_readable'][$inc])) {
		// Construct FQFN
		$FQFN = getPath() . $inc;

		// Is it readable and at least 50 byte large? Include file sizes < 50 byte are always deprecated
		$GLOBALS['inc_readable'][$inc] = ((isFileReadable($FQFN)) && (filesize($FQFN) >= 50));
	} // END - if

	// Return result
	return $GLOBALS['inc_readable'][$inc];
}

// [EOF]
?>
